@@ -16,7 +16,7 @@ import json
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, freqly_pkl_file_name='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon'):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, freqly_pkl_file_name='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',nb_items_per_year=252):
         super().__init__()
         self.freqly_pkl_file_name=freqly_pkl_file_name
         self.local_root_directory=local_root_directory
@@ -25,6 +25,7 @@ class AbstractRunner(ABC):
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.running_date = running_date
         self.starting_date = starting_date
+        self.nb_items_per_year = nb_items_per_year
 
     @abstractmethod
     def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs):
@@ -33,7 +34,6 @@ class AbstractRunner(ABC):
 class SimpleSignalRunner(AbstractRunner):
     def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization):
         saving_key, idios = saver.create_saving_key(seed, trigger, signal_type, idios_string, transaction_costs, normalization)
-        lookback_window = idios['lookback_window']
         check_run_existence, table_number = saver.checkRunExistence(saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(saving_key)
         assert check_run_existence == exhaustive_check_run_existence
@@ -58,7 +58,7 @@ class SimpleSignalRunner(AbstractRunner):
         if signal_type == 'long_only':
             freqly_df['signal']=1.
         else:
-
+            lookback_window = idios['lookback_window']
             skipping_size = lookback_window
             # kwargs = {**generics, **idios}
             signal_generation_method_to_call = getattr(signal_generator, signal_type)
@@ -71,8 +71,8 @@ class SimpleSignalRunner(AbstractRunner):
                 print(inst)
                 return
         freqly_df = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs , normalization = normalization)
-        sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= 252 * 24, from_ret=True)
-        sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period= 252 * 24, from_ret=True)
+        sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= self.nb_items_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period= self.nb_items_per_year, from_ret=True)
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
