@@ -211,6 +211,47 @@ def alpha_6_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
     data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
     data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
 
+    data['volu_close'] = data['aggregated_volume'] * data['close']
+    correlation_coefficient_op_vol = compute_correlation(data['open'], data['aggregated_volume'])
+
+    data['volu_close_pct_rank']=data['volu_close'].rank(pct = True)
+    trend_rank = data['volu_close_pct_rank'].iloc[-1]
+
+    if correlation_coefficient_op_vol > vol_threshold:
+        if trend_rank > up_trend_threshold:
+            return contravariant
+        else:
+            return np.nan
+    else :
+        return np.nan
+
+def alpha_6_ls(data = None, vol_threshold = 0.8, low_trend_threshold =0.2, up_trend_threshold=0.8, contravariant = -1., lag = 2, **kwargs):
+    ## aggregating the volumes by lag
+    data.index = range(0,len(data))
+    all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
+    data['aggregated_indice'] = np.nan
+    data['aggregated_indice'].loc[all_indices] = all_indices
+    data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
+    data['aggregated_indice'] = data['aggregated_indice'].astype(int)
+    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    high = data.groupby(['aggregated_indice'])['high'].agg('max')
+    low = data.groupby(['aggregated_indice'])['low'].agg('min')
+
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_high'] =  data['aggregated_indice'].map(high)
+    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+
+    data = data[::-lag]
+    data = data.iloc[::-1]
+
+    data['hl'] = (data['aggregated_high'] - data['aggregated_low'])/data['aggregated_low']
+    data['volu_hi_low'] = data['aggregated_volume']*data['hl']
+
+    data['close_ret']=data['close'].pct_change()
+
+    data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
+    data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
+
     ##### after
     data['volu_close'] = data['aggregated_volume']*data['close']
     vwap_close = data['volu_close'].sum() / data['aggregated_volume'].sum()
@@ -225,20 +266,20 @@ def alpha_6_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
     data['open_minus_vwap'] = data.open - vwap_open
     data['close_minus_vwap'] = data.close - vwap_close
 
-    correlation_coefficient_op_vol = compute_correlation(data['open'], data['aggregated_volume'])
+    last_close = data['close'].iloc[-1]
 
-    data['close_minus_vwap_pct_rank']=data['close_minus_vwap'].rank(pct = True)
-    trend_rank = data['close_minus_vwap_pct_rank'].iloc[-1]
+    data['volu_close'] = data['aggregated_volume'] * data['close']
+    vol_rank = compute_correlation(data['open'], data['aggregated_volume'])
 
-    if correlation_coefficient_cl_op > vol_threshold:
-        if trend_rank > up_trend_threshold:
+    data['volu_close_pct_rank']=data['volu_close'].rank(pct = True)
+    trend_rank = data['volu_close_pct_rank'].iloc[-1]
+    if vol_rank > vol_threshold:
+        if last_close > vwap_close:
             return contravariant
         else:
-            return np.nan
+            return -contravariant
     else :
         return np.nan
-
-
 def alpha_6(data = None, contravariant = -1., **kwargs):
     correlation_coefficient = compute_correlation(data['open'], data['volumefrom'])
     return contravariant*correlation_coefficient
